box_scores_detailed: Player-level box score data from the Australian Women's...

Description Usage Format Source

Description

box_scores_detailed contains box scores data at the player-level (one row per player per competing team), from games played in the Australian Women's National Basketball League. Includes common basketball metrics such as points scored, rebounds, assists, steals, and so on. The box_scores_detailed data set currently contains publicly available data from games played in the 2014/2015 season to the 2020 season, inclusive.

Usage

1

Format

A tibble with 12973 rows and 40 variables:

season

Numeric. Season of competition. Note that WNBL seasons typically overlap year-end. For simplicity, the first year of competition is included in the season variable, e.g., "2014" represents the 2014 / 2015 season.

page_id

Numeric. Unique identifier for each game. View the game stats in your browser by navigating to https://www.fibalivestats.com/u/wnbl/<page_id>/

team_name

Character. Team name for the player listed on each row.

team_short_name

Character. Team nickname for the player listed on each row.

home_away_flag

Character. Identifying whether the team represented on each row was the home or away team.

team_name_opp

Character. Opposition team name.

team_short_name_opp

Character. Opposition team nickname.

first_name

Character. Player's first name.

family_name

Character. Player's family name.

scoreboard_name

Character. Player's name as it appears on a scoreboard (e.g., Sara Blicavs = S. Blicavs).

playing_position

Character. Player's typical on-court position. G = Guard, F = Forward, C = Centre).

starter

Numeric. Flagging variable to indicate whether the player started on-court for any given game or not. Started on-court: starter == 1, started on the bench: starter == 0.

minutes

Character. Player's minutes played, in mm:ss.

points

Numeric. Number of points scored by the player listed in scoreboard_name.

points_second_chance

Numeric. Number of second-chance points.

points_fast_break

Numeric. Number of points from fast breaks.

points_in_the_paint

Numeric. Number of points scored in the key area (colloquially, "in the paint").

points_from_turnovers

Numeric. Number of points scored from turnovers.

field_goals_made

Numeric. Number of successful field goals.

field_goals_attempted

Numeric. Number of attempted field goals.

field_goals_percentage

Numeric. field_goals_made divided by field_goals_attempted multiplied by 100.

three_pointers_made

Numeric. Number of successful field goals.

three_pointers_attempted

Numeric. Number of attempted field goals

three_pointers_percentage

Numeric. three_pointers_made divided by three_pointers_attempted multiplied by 100.

two_pointers_made

Numeric. Number of two-point field goals made.

two_pointers_attempted

Numeric. Number of two-point field goals attempted.

two_pointers_percentage

Numeric. two_pointers_made divided by two_pointers_attempted multiplied by 100.

free_throws_made

Numeric. Number of free throws made.

free_throws_attempted

Numeric. Number of free throws attempted.

free_throws_percentage

Numeric. free_throws_made divided by free_throws_attempted multiplied by 100.

rebounds_defensive

Numeric. Total number of defensive rebounds.

rebounds_offensive

Numeric. Total number of offensive rebounds.

rebounds_total

Numeric. Total number of rebounds, rebounds_defensive plus rebounds_offensive.

assists

Numeric. Number of assists.

turnovers

Numeric. Number of turnovers.

steals

Numeric. Number of steals.

blocks

Numeric. Number of blocks.

blocks_received

Numeric. Number of blocks received.

fouls_personal

Numeric. Number of personal fouls.

fouls_on

Numeric. Number of fouls on.

Australian Women's National Basketball League website https://www.wnbl.com.au


jacquietran/wnblr documentation built on Jan. 8, 2022, 1:13 a.m.