Description Usage Format Source
box_scores_detailed contains box scores data at the player-level (one row per player per competing team), from games played in the Australian Women's National Basketball League. Includes common basketball metrics such as points scored, rebounds, assists, steals, and so on. The box_scores_detailed data set currently contains publicly available data from games played in the 2014/2015 season to the 2020 season, inclusive.
1 |
A tibble with 12973 rows and 40 variables:
Numeric. Season of competition. Note that WNBL seasons typically overlap year-end. For simplicity, the first year of competition is included in the season variable, e.g., "2014" represents the 2014 / 2015 season.
Numeric. Unique identifier for each game. View the game stats in your browser by navigating to https://www.fibalivestats.com/u/wnbl/<page_id>/
Character. Team name for the player listed on each row.
Character. Team nickname for the player listed on each row.
Character. Identifying whether the team represented on each row was the home or away team.
Character. Opposition team name.
Character. Opposition team nickname.
Character. Player's first name.
Character. Player's family name.
Character. Player's name as it appears on a scoreboard (e.g., Sara Blicavs = S. Blicavs).
Character. Player's typical on-court position. G = Guard, F = Forward, C = Centre).
Numeric. Flagging variable to indicate whether the player started on-court for any given game or not. Started on-court: starter == 1, started on the bench: starter == 0.
Character. Player's minutes played, in mm:ss.
Numeric. Number of points scored by the player listed in scoreboard_name.
Numeric. Number of second-chance points.
Numeric. Number of points from fast breaks.
Numeric. Number of points scored in the key area (colloquially, "in the paint").
Numeric. Number of points scored from turnovers.
Numeric. Number of successful field goals.
Numeric. Number of attempted field goals.
Numeric. field_goals_made divided by field_goals_attempted multiplied by 100.
Numeric. Number of successful field goals.
Numeric. Number of attempted field goals
Numeric. three_pointers_made divided by three_pointers_attempted multiplied by 100.
Numeric. Number of two-point field goals made.
Numeric. Number of two-point field goals attempted.
Numeric. two_pointers_made divided by two_pointers_attempted multiplied by 100.
Numeric. Number of free throws made.
Numeric. Number of free throws attempted.
Numeric. free_throws_made divided by free_throws_attempted multiplied by 100.
Numeric. Total number of defensive rebounds.
Numeric. Total number of offensive rebounds.
Numeric. Total number of rebounds, rebounds_defensive plus rebounds_offensive.
Numeric. Number of assists.
Numeric. Number of turnovers.
Numeric. Number of steals.
Numeric. Number of blocks.
Numeric. Number of blocks received.
Numeric. Number of personal fouls.
Numeric. Number of fouls on.
Australian Women's National Basketball League website https://www.wnbl.com.au
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.